@@ -1,7 +1,7 @@
 <?PHP
 
    /*
-    *  S/MIME 0.5
+    *  S/MIME 0.6
     *  this release Wouter Teepe <wouter@teepe.com> and Antonio Vasconcelos
     *  (c) 2003 (GNU GPL - see ../../COPYING)
     *
@@ -40,9 +40,8 @@
     *
     */
 
-   chdir("..");
    if (!defined('SM_PATH'))
-      define('SM_PATH','../');
+      define('SM_PATH','../../');
 
    if (file_exists(SM_PATH . 'include/validate.php')) {
       include_once(SM_PATH . 'include/validate.php');
@@ -50,10 +49,9 @@
       if (file_exists(SM_PATH . 'src/validate.php'))
          include_once(SM_PATH . 'src/validate.php');
    }
-   include_once("../plugins/smime/functions.php");
+   include_once(SM_PATH . 'plugins/smime/functions.php');
 
-# [vasco]
-	if(!isset($cert)) $cert=$_GET['cert'];
+   sqgetGlobalVar('cert', $cert, SQ_GET);
 
    header("Pragma: ");
    header("Cache-Control: cache");
