@@ -1,7 +1,7 @@
 <?php
 
    /*
-    *  S/MIME 0.5
+    *  S/MIME 0.6
     *  this release Wouter Teepe <wouter@teepe.com> and Antonio Vasconcelos
     *  (c) 2003 (GNU GPL - see ../../COPYING)
     *
@@ -40,9 +40,8 @@
     *
     */
 
-   chdir("..");
    if (!defined('SM_PATH'))
-      define('SM_PATH','../');
+      define('SM_PATH','../../');
    
    if (file_exists(SM_PATH . 'include/validate.php')) {
       include_once(SM_PATH . 'include/validate.php');
@@ -51,23 +50,13 @@
          include_once(SM_PATH . 'src/validate.php');
    }
 
-   include_once("../functions/page_header.php");
-   
-   if (file_exists(SM_PATH . 'include/load_prefs.php')) {
-      include_once(SM_PATH . 'include/load_prefs.php');
-   } else {
-      if (file_exists(SM_PATH . 'src/load_prefs.php'))
-         include_once(SM_PATH . 'src/load_prefs.php');
-   }
+   include_once(SM_PATH . 'plugins/smime/functions.php');
 
-   require_once("../plugins/smime/functions.php");
-
-# [vasco]
-   if(!isset($cert)) $cert=$_GET['cert'];
-   if(!isset($mailbox)) $mailbox=$_GET['mailbox'];
-   if(!isset($passed_id)) $passed_id=$_GET['passed_id'];
-   if(!isset($startMessage)) $startMessage=$_GET['startMessage'];
-   if(!isset($show_more)) $show_more=$_GET['show_more'];
+   sqgetGlobalVar('cert', $cert, SQ_GET);
+   sqgetGlobalVar('mailbox', $mailbox, SQ_GET);
+   sqgetGlobalVar('passed_id', $passed_id, SQ_GET);
+   sqgetGlobalVar('startMessage', $startMessage, SQ_GET);
+   sqgetGlobalVar('show_more', $show_more, SQ_GET);
 
 
    function x509_match($a, $b) {
@@ -91,7 +80,8 @@
    function x509_open($cert) {
       global $cert_in_dir, $openssl;
       $lines = array();
-      exec("$openssl x509 -in $cert_in_dir$cert -subject -issuer -dates -serial -fingerprint -noout 2>/tmp/err",
+      $safe_cert = escapeshellarg("$cert_in_dir$cert");
+      exec("$openssl x509 -in $safe_cert -subject -issuer -dates -serial -fingerprint -noout 2>/tmp/err",
          $lines);
       return array(
          x509_split(x509_match($lines[0], "subject="), "", "\n"),
